pub struct CommitRequest {
pub database_id: Option<String>,
pub mode: Option<String>,
pub mutations: Option<Vec<Mutation>>,
pub single_use_transaction: Option<TransactionOptions>,
pub transaction: Option<Vec<u8>>,
}Expand description
The request for Datastore.Commit.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- commit projects (request)
Fields
database_id: Option<String>The ID of the database against which to make the request. ‘(default)’ is not allowed; please use empty string ‘’ to refer the default database.
mode: Option<String>The type of commit to perform. Defaults to TRANSACTIONAL.
mutations: Option<Vec<Mutation>>The mutations to perform. When mode is TRANSACTIONAL, mutations affecting a single entity are applied in order. The following sequences of mutations affecting a single entity are not permitted in a single Commit request: - insert followed by insert - update followed by insert - upsert followed by insert - delete followed by update When mode is NON_TRANSACTIONAL, no two mutations may affect a single entity.
single_use_transaction: Option<TransactionOptions>Options for beginning a new transaction for this request. The transaction is committed when the request completes. If specified, TransactionOptions.mode must be TransactionOptions.ReadWrite.
transaction: Option<Vec<u8>>The identifier of the transaction associated with the commit. A transaction identifier is returned by a call to Datastore.BeginTransaction.