pub struct LookupResponse {
pub deferred: Option<Vec<Key>>,
pub found: Option<Vec<EntityResult>>,
pub missing: Option<Vec<EntityResult>>,
pub read_time: Option<DateTime<Utc>>,
pub transaction: Option<Vec<u8>>,
}Expand description
The response for Datastore.Lookup.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- lookup projects (response)
Fields
deferred: Option<Vec<Key>>A list of keys that were not looked up due to resource constraints. The order of results in this field is undefined and has no relation to the order of the keys in the input.
found: Option<Vec<EntityResult>>Entities found as ResultType.FULL entities. The order of results in this field is undefined and has no relation to the order of the keys in the input.
missing: Option<Vec<EntityResult>>Entities not found as ResultType.KEY_ONLY entities. The order of results in this field is undefined and has no relation to the order of the keys in the input.
read_time: Option<DateTime<Utc>>The time at which these entities were read or found missing.
transaction: Option<Vec<u8>>The identifier of the transaction that was started as part of this Lookup request. Set only when ReadOptions.new_transaction was set in LookupRequest.read_options.