pub struct RunQueryRequest {
pub database_id: Option<String>,
pub explain_options: Option<ExplainOptions>,
pub gql_query: Option<GqlQuery>,
pub partition_id: Option<PartitionId>,
pub property_mask: Option<PropertyMask>,
pub query: Option<Query>,
pub read_options: Option<ReadOptions>,
}Expand description
The request for Datastore.RunQuery.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- run query projects (request)
Fields
database_id: Option<String>The ID of the database against which to make the request. ‘(default)’ is not allowed; please use empty string ‘’ to refer the default database.
explain_options: Option<ExplainOptions>Optional. Explain options for the query. If set, additional query statistics will be returned. If not, only query results will be returned.
gql_query: Option<GqlQuery>The GQL query to run. This query must be a non-aggregation query.
partition_id: Option<PartitionId>Entities are partitioned into subsets, identified by a partition ID. Queries are scoped to a single partition. This partition ID is normalized with the standard default context partition ID.
property_mask: Option<PropertyMask>The properties to return. This field must not be set for a projection query. See LookupRequest.property_mask.
query: Option<Query>The query to run.
read_options: Option<ReadOptions>The options for this query.